<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>CheckUpdate</name>
    <message>
        <source>Last check: </source>
        <translation>Ostatnie sprawdzenie: </translation>
    </message>
</context>
<context>
    <name>QuitTestingChannelDialog</name>
    <message>
        <source>If you exit the beta program, you will no longer receive beta updates.</source>
        <translation>Jeśli opuścisz program Beta, przestaniesz otrzymywać aktualizacje z tego kanału.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Wyjdź</translation>
    </message>
</context>
<context>
    <name>UpdateControl</name>
    <message>
        <source>View Update Log</source>
        <translation>Pokaż dziennik aktualizacji</translation>
    </message>
</context>
<context>
    <name>UpdateHistoryDialog</name>
    <message>
        <source>Update History</source>
        <translation>Historia aktualizacji</translation>
    </message>
    <message>
        <source>No update history</source>
        <translation>Brak historii aktualizacji</translation>
    </message>
    <message>
        <source>System Updates</source>
        <translation>Aktualizacje systemu</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>Aktualizacje bezpieczeństwa</translation>
    </message>
    <message>
        <source>Delivers a cumulative update including new features, quality updates, and security updates</source>
        <translation>Zapewnia cały pakiet aktualizacji, w tym nowe funkcje, usprawnienia i aktualizacje bezpieczeństwa</translation>
    </message>
    <message>
        <source>Delivers security updates</source>
        <translation>Zapewnia aktualizacje bezpieczeństwa</translation>
    </message>
    <message>
        <source>Installation date:</source>
        <translation>Data instalacji: </translation>
    </message>
</context>
<context>
    <name>UpdateList</name>
    <message>
        <source>View Details</source>
        <translation>Wyświetl szczegóły</translation>
    </message>
    <message>
        <source>Release time:</source>
        <translation>Data wydania:</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Zwiń</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Wersja:</translation>
    </message>
</context>
<context>
    <name>UpdateLogDialog</name>
    <message>
        <source>Update Log</source>
        <translation>Dziennik aktualizacji</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <source>Export to desktop</source>
        <translation>Wyślij na pulpit</translation>
    </message>
</context>
<context>
    <name>UpdateLogHelper</name>
    <message>
        <source>NONE</source>
        <translation>BRAK</translation>
    </message>
    <message>
        <source>LOW</source>
        <translation>NISKIE</translation>
    </message>
    <message>
        <source>MEDIUM</source>
        <translation>ŚREDNIE</translation>
    </message>
    <message>
        <source>HIGH</source>
        <translation>WYSOKIE</translation>
    </message>
    <message>
        <source>CRITICAL</source>
        <translation>KRYTYCZNE</translation>
    </message>
    <message>
        <source>critical-risk</source>
        <translation>ryzyko-krytyczne</translation>
    </message>
    <message>
        <source>high-risk</source>
        <translation>ryzyko-wysokie</translation>
    </message>
    <message>
        <source>medium-risk</source>
        <translation>ryzyko-średnie</translation>
    </message>
    <message>
        <source>low-risk</source>
        <translation>ryzyko-niskie</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>nieznany</translation>
    </message>
    <message>
        <source>This update fixes</source>
        <translation>Ta aktualizacja naprawia</translation>
    </message>
    <message>
        <source>vulnerabilities</source>
        <translation>luki zabezpieczeń</translation>
    </message>
    <message>
        <source>vulnerability</source>
        <translation>lukę zabezpieczeń</translation>
    </message>
    <message>
        <source>%1 of %2 %3</source>
        <translation>%1 z %2 %3</translation>
        <extra-content_explain>`数字+%`会在代码中替换为字符串，例如：3 of high-risk vulnerabilities；各语言需要根据实际情况增加空格(例如：中文没有空格，英文有空格)</extra-content_explain>
    </message>
    <message>
        <source>, </source>
        <translation>, </translation>
        <extra-content_explain>中文逗号不需要空格，英文逗号需要空格For more details, please visit</extra-content_explain>
    </message>
    <message>
        <source>for more details, please visit </source>
        <translation>Aby uzyskać więcej informacji, odwiedź: </translation>
        <extra-content_explain>这句话后面会带上一个超链接，各语言自行决定末尾需不需要加空格</extra-content_explain>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Checking for updates, please wait…</source>
        <translation>Sprawdzanie aktualizacji, proszę czekać...</translation>
    </message>
    <message>
        <source>Your system is up to date</source>
        <translation>Twój system jest aktualny</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Nieznany błąd</translation>
    </message>
    <message>
        <source>Downloading updates failed. Please free up %1 disk space first.</source>
        <translation>Błąd pobierania aktualizacji. Najpierw zwolnij %1 miejsca na dysku.</translation>
    </message>
    <message>
        <source>Dependency error, failed to detect the updates</source>
        <translation>Błąd zależności, nie udało się wykryć aktualizacji</translation>
    </message>
    <message>
        <source>Please check your network and try again.</source>
        <translation>Sprawdź swoją sieć i spróbuj ponownie.</translation>
    </message>
    <message>
        <source>Downloading updates failed. Please check your network and try again.</source>
        <translation>Błąd pobierania aktualizacji. Sprawdź swoją sieć i spróbuj ponownie.</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Nie udało się utworzyć kopii zapasowej. Kontynuując, nie będzie można przywrócić starego systemu.</translation>
    </message>
    <message>
        <source>If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Kontynuując, nie będzie można przywrócić starego systemu.</translation>
    </message>
    <message>
        <source>Insufficient disk space</source>
        <translation>Za mało miejsca na dysku</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>Błąd DPKG</translation>
    </message>
    <message>
        <source>File missing</source>
        <translation>Brakuje pliku</translation>
    </message>
    <message>
        <source>Service connection is abnormal, please check the network and try again</source>
        <translation>Występują problemy połączenia z usługą, sprawdź sieć i spróbuj ponownie.</translation>
    </message>
    <message>
        <source>The repository source configuration is not valid, please check and try again.</source>
        <translation>Konfiguracja repozytorium źródłowego jest nieprawidłowa, sprawdź i spróbuj ponownie.</translation>
    </message>
    <message>
        <source>Check Again</source>
        <translation>Sprawdź ponownie</translation>
    </message>
    <message>
        <source>Privacy Policy</source>
        <translation>Politykę prywatności</translation>
    </message>
    <message>
        <source>To use this software, you must accept the %1 that accompanies software updates.</source>
        <translation>Aby korzystać z tego oprogramowania, musisz zaakceptować %1, dołączoną do aktualizacji.</translation>
    </message>
    <message>
        <source>Turn on the switches under Update Content to get better experiences</source>
        <translation>Sprawdź ustawienia, aby usprawnić proces aktualizacji</translation>
    </message>
    <message>
        <source>Your system is not activated, and it failed to connect to update services</source>
        <translation>Twój system nie jest aktywowany i nie udało mu się połączyć z usługą aktualizacji</translation>
    </message>
    <message>
        <source>The system updates are disabled. Please contact your administrator for help</source>
        <translation>Aktualizacje systemu są wyłączone. Skontaktuj się z administratorem, aby uzyskać pomoc</translation>
    </message>
    <message>
        <source>The system has enabled auto recovery function and does not support updates. If you have any questions, please contact the enterprise administrator</source>
        <translation>System posiada włączoną funkcję automatycznego przywracania i nie wspiera aktualizacji. Jeśli posiadasz jakiekolwiek pytania, skontaktuj się z administratorem.</translation>
    </message>
</context>
<context>
    <name>UpdateSelectDialog</name>
    <message>
        <source>The updates have been already downloaded. What do you want to do?</source>
        <translation>Aktualizacje zostały pobrane. Co chcesz zrobić?</translation>
    </message>
    <message>
        <source>Silent Installation</source>
        <translation>Cicha instalacja</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>Zaktualizuj i uruchom ponownie</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>Zaktualizuj i zamknij</translation>
    </message>
</context>
<context>
    <name>UpdateSetting</name>
    <message>
        <source>Smart Mirror Switch</source>
        <translation>Inteligentne przełączanie mirrorów</translation>
    </message>
    <message>
        <source>Update Type</source>
        <translation>Typ aktualizacji</translation>
    </message>
    <message>
        <source>Function Updates</source>
        <translation>Aktualizacje funkcjonalności</translation>
    </message>
    <message>
        <source>Delivers a cumulative update including new features, quality updates, and  security updates</source>
        <translation>Zapewnia cały pakiet aktualizacji, w tym nowe funkcje, usprawnienia i aktualizacje bezpieczeństwa</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>Aktualizacje bezpieczeństwa</translation>
    </message>
    <message>
        <source>Delivers security updates</source>
        <translation>Zapewnia aktualizacje bezpieczeństwa</translation>
    </message>
    <message>
        <source>Third-party Updates</source>
        <translation>Aktualizacje stron trzecich</translation>
    </message>
    <message>
        <source>Delivers  updates for additional repository sources</source>
        <translation>Zapewnia aktualizacje dla dodatkowych repozytoriów</translation>
    </message>
    <message>
        <source>Limit Speed</source>
        <translation>Limit prędkości</translation>
    </message>
    <message>
        <source>Limit Setting</source>
        <translation>Ustawienia limitu</translation>
    </message>
    <message>
        <source>Auto Download</source>
        <translation>Automatyczne pobieranie</translation>
    </message>
    <message>
        <source>Enabling &quot;Auto Download Updates&quot; will automatically download updates when connected to the internet</source>
        <translation>Włączenie &quot;Automatyczne pobieranie aktualizacji&quot; automatycznie zainstaluje aktualizacje po wykryciu połączenia z Internetem</translation>
    </message>
    <message>
        <source>Download when Inactive</source>
        <translation>Pobieraj w stanie bezczynności</translation>
    </message>
    <message>
        <source>Start at</source>
        <translation>Rozpocznij o</translation>
    </message>
    <message>
        <source>End at</source>
        <translation>Zakończ o</translation>
    </message>
    <message>
        <source>Advanced Settings</source>
        <translation>Ustawienia zaawansowane</translation>
    </message>
    <message>
        <source>Updates Notification</source>
        <translation>Powiadomienia aktualizacji</translation>
    </message>
    <message>
        <source>Clear Package Cache</source>
        <translation>Wyczyść pamięć podręczną pakietów</translation>
    </message>
    <message>
        <source>Update History</source>
        <translation>Historia aktualizacji</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Wyświetl</translation>
    </message>
    <message>
        <source>Join Internal Testing Channel</source>
        <translation>Dołącz do wewnętrznego kanału testowego</translation>
    </message>
    <message>
        <source>Click here to complete the application</source>
        <translation>Kliknij tutaj, aby zakończyć aplikacje</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Rozwiń</translation>
    </message>
    <message>
        <source>Forum users at level 2 and above can join the beta test to receive the latest updates.</source>
        <translation>Użytkownicy forum na poziomie 2 lub wyższym mogą dołączyć do testów Beta i uzyskać najnowsze aktualizacje.</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Zwiń</translation>
    </message>
    <message>
        <source>Only numbers between 1-99999 are allowed</source>
        <translation>Dozwolone są tylko liczby w zakresie 1-99999</translation>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>System Updates</source>
        <translation>Aktualizacje systemu</translation>
    </message>
    <message>
        <source>Fixed some known bugs and security vulnerabilities</source>
        <translation>Naprawiono kilka znanych błędów i luk bezpieczeństwa</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>Aktualizacje bezpieczeństwa</translation>
    </message>
    <message>
        <source>Third-party Repositories</source>
        <translation>Zewnętrzne repozytoria</translation>
    </message>
    <message>
        <source>updatelog</source>
        <translation>Dziennik aktualizacji</translation>
    </message>
    <message>
        <source>Log export failed, please try again</source>
        <translation>Błąd eksportowania dzienników, spróbuj ponownie</translation>
    </message>
    <message>
        <source>The log has been exported to the desktop</source>
        <translation>Wysłano dzienniki na pulpit</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Aktualizuj</translation>
    </message>
</context>
<context>
    <name>update</name>
    <message>
        <source>System Update</source>
        <translation>Aktualizacje systemu</translation>
    </message>
    <message>
        <source>System update and upgrade</source>
        <translation>Aktualizacje systemu</translation>
    </message>
</context>
<context>
    <name>updateMain</name>
    <message>
        <source>Update Settings</source>
        <translation>Ustawienia aktualizacji</translation>
    </message>
    <message>
        <source>Installing</source>
        <translation>Instalowanie</translation>
    </message>
    <message>
        <source>Update download completed</source>
        <translation>Nie udało się pobrać aktualizacji</translation>
    </message>
    <message>
        <source>Install updates</source>
        <translation>Zainstaluj aktualizacje</translation>
    </message>
    <message>
        <source>Update size: </source>
        <translation>Rozmiar aktualizacji: </translation>
    </message>
    <message>
        <source>Update download failed</source>
        <translation>Nie udało się pobrać aktualizacji</translation>
    </message>
    <message>
        <source>Downloading updates...</source>
        <translation>Pobieranie aktualizacji...</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Pobieranie</translation>
    </message>
    <message>
        <source>Configure Update settings、Security Updates、Auto Download Updates and Updates Notification</source>
        <translation>Konfiguracja ustawień aktualizacji, aktualizacje bezpieczeństwa, pobieranie i powiadomienia aktualizacji</translation>
    </message>
    <message>
        <source>Reboot now</source>
        <translation>Uruchom ponownie teraz</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Pobierz</translation>
    </message>
    <message>
        <source>Installing updates...</source>
        <translation>Instalowanie aktualizacji...</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation>Ponów</translation>
    </message>
    <message>
        <source>Continue Update</source>
        <translation>Wznów aktualizacje</translation>
    </message>
    <message>
        <source>Updates Available</source>
        <translation>Aktualizacje są dostępne</translation>
    </message>
    <message>
        <source>Installation update failed</source>
        <translation>Błąd instalowania aktualizacji</translation>
    </message>
    <message>
        <source>To ensure proper functioning of your system and applications, please restart your computer after the update</source>
        <translation>Aby zapewnić prawidłowe działanie systemu i aplikacji, uruchom ponownie komputer po zaktualizowaniu</translation>
    </message>
    <message>
        <source>Backing up in progress...</source>
        <translation>Tworzenie kopii zapasowej...</translation>
    </message>
    <message>
        <source>Backing up in progress</source>
        <translation>Tworzenie kopii zapasowej</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>Błąd tworzenia kopii zapasowej</translation>
    </message>
    <message>
        <source>Update installation successful</source>
        <translation>Aktualizacja zainstalowana pomyślnie</translation>
    </message>
    <message>
        <source>If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Kontynuując, nie będzie można przywrócić starego systemu.</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>Spróbuj ponownie</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>Przejdź do aktualizacji</translation>
    </message>
    <message>
        <source>The battery capacity is lower than 60%. To get successful updates, please plug in.</source>
        <translation>Poziom naładowania spadł poniżej 60%. Podłącz zasilanie, aby uniknąć problemów podczas aktualizacji.</translation>
    </message>
</context>
</TS>